/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, në {1}. të {2}"

, "Recurrances"
: "Përsëritje"

, "No recurring rule defined"
: "Nuk është përcaktuar një rregull përseritës"

, "Details"
: "Detaje"

, "None"
: "Asnjë"

, "Daily"
: "I Përditshëm"

, "Weekly"
: "I Përjavshëm"

, "Monthly"
: "I Përmuajshëm"

, "Yearly"
: "I Përvitshëm"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Përjashtimet e ngjarjeve përsëritëse nuk mund të përsërisin vetvehten"

, "at"
: "në"

, "never"
: "asnjëherë"

, "after {0} occurrences"
: "pas {0} ndodhive"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Fund"

, "Until has to be after event start"
: "Derisa të jetë pasi ngjarja fillon"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Çdo {0}. Ditë"

, "Every {0}. Week at"
: "Çdo {0}. Javë në"

, "Every {0}. Month"
: "Çdo {0}. Muaj"

, "at the"
: "Në"

, "first"
: "i pari"

, "second"
: "i dyti"

, "third"
: "i treti"

, "fourth"
: "i katërti"

, "last"
: "i fundit"

, "Every {0}. Year"
: "Çdo {0}. Vit"

, "of"
: "e"

, "Summary"
: "Përmbledhje"

, "Organizer"
: "Organizuesi"

, "Description"
: "Përshkrimi"

, "Location"
: "Vëndi"

, "Start Time"
: "Koha e fillimit"

, "End Time"
: "Koha e mbarimit"

, "Attendee"
: "Vijues"

, "whole day"
: "të gjithë ditën"

, "Week {0} :"
: "Java {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Ngjarje e Re"

, "Calendar, Calendars"
: [
  "Kalendar"
 ,"Kalendarë"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Shto vijues"

, "Sort Attendee"
: "Rradhit Vijuesit"

, "Check to filter for this attendee"
: "Kontrollo tek filtri për këtë vijues"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Duke ngarkuar ngjarjet, ju lutem prisni..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Printo Faqen"

, "Loose-Leaf"
: ""

, "Sheet"
: "Tabelë"

, "Grid"
: "Rrjet"

, "Timeline"
: ""

, "Day"
: "Ditë"

, "Week"
: "Javë"

, "Month"
: "Muaj"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Vendos përgjigjen time"

, "Copy {0}"
: "Kopje {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Duke përditësuar ngjarjen në të shkuarën"

, "Update this event"
: "Përditëso këtë ngjarje"

, "Do not update this event"
: "Mos përditëso këtë ngjarje"

, "Creating event in the past"
: "Duke krijuar ngjarje në të shkuarën"

, "Create this event"
: "Krijo këtë ngjarje"

, "Do not create this event"
: "Mos krijo këte ngjarje"

, "Update this event only"
: "Përditëso vetëm këtë ngjarje"

, "Update this and all future events"
: "Përditëso këtë dhe të gjithë ngjarjet e ardhshme"

, "Update whole series"
: "Përditëso te gjithë seritë"

, "Update nothing"
: "Mos përditëso asgjë"

, "Update Event"
: "Përditëso ngjarjen"

, "Please Change Selection"
: "Ju lutemi ndryshoni Zgjedhjet"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Zgjedhja juaj përmban ngjarje të përërituar. Ngjarjet e përsëritura duhet të fshihen veçmas"

, "Delete Event"
: "Fshij ngjaren"

, "Delete this event only"
: "Fshij vetëm këtë ngjarje"

, "Delete this and all future events"
: "Fshij këtë dhe gjithë ngjarjet e ardhshme"

, "Delete whole series"
: "Fshij të gjithë serinë"

, "Delete nothing"
: "Mos fshij asgjë"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Doni vërtetë të fshini këtë ngjarje?"
 ,"Doni vertetë të fshini këto ngjarje"

]
, "Could not Print"
: "Nuk mund të Printohej"

, "Sorry, your current view does not support printing."
: "Na falni, pamja juaj e shfaqur aktualisht nuk përmban printimin"

, "Scheduling Conflict"
: "Duke planifikuar konfliktin"

, "The following attendee are busy at the requested time:"
: "Vijuesit e mëposhtëm janë të zënë në kohën e kërkuar"

, "Ignore Conflict"
: "Injoro konfliktin"

, "Edit Event"
: "Modifiko ngjarjen"

, "Cancel this action"
: "Anullo këtë veprim"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Menaxho Burimet"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Zgjidhni Vijues"

, "Attachments"
: ""

, "Private"
: "Private"

, "Tags"
: "Etiketa"

, "Blocking"
: "Bllokim"

, "Tentative"
: "E paqarte"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "klasifikim privat"

, "recurring event"
: "ngjarje periodike"

, "recurring event exception"
: "përjashtim i ngjarjes periodike"

, "has alarm"
: "ka alarm"

, "has attachments"
: "ka bashkangjitje"

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini Kalendar"

, "WK"
: "JV"

, "{0} more..."
: "{0} më shumë..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Lutemi zgjidhni Ngjarjen ku të shtohen kontaktet"

, "Role"
: "Role"

, "Select Role"
: "Zgjidhni Rolin"

, "Status"
: "Statusi"

, "Select Status"
: "Zgjidhni Statusin"

, "Adding {0} Attendee to event"
: "Duke i shtuar {0} vijues ngjarjes"

, "no events found"
: "nuk u gjendën ngjarje"

, "Searching..."
: "Duke Kërkuar"

, "Search Event"
: "Kërko Ngjarje"

, "Event, Events"
: [
  "Ngjarje"
 ,"Ngjarje"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "jo-bllokuar"

, "Displayed in"
: "E shfaqur në"

, "No Information"
: "Nuk ka informacion"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Ngjarje"

, "Calendars"
: "Kalendarë"

, "Quick Search"
: "Kërkim i Shpejtë"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Statusi i Vijuesit"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Roli i Vijuesit"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Klasifikimi"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: "Date e panjohur"

, "{0} {1} o'clock"
: "Ora {0} {1} "

, "Event (as attendee)"
: "Ngjarje (si vijues)"

, "Event (as organizer)"
: "Ngjarje (si organizues)"

, "Event attendee"
: "Vijues ngjarjeje"

, "Attender, Attendee"
: [
  "Vijues"
 ,"Vijues"

]
, "Resource, Resources"
: [
  "Burim"
 ,"Burime"

]
, "Resources"
: "Burime"

, "Anyone"
: ""

, "Name"
: "Emri"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "E-Postë"

, "Maximum number of attendee"
: ""

, "Type"
: "Tipi"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Kliko këtu për të ftuar një vijues tjetër"

, "User"
: "Përdorues"

, "Group"
: "Grup"

, "Member of group"
: "Pjesëtar i grupit"

, "This is the calendar where the attender has saved this event in"
: "Ky është kalendari ku vijuesi ka ruajtur këtë ngjarje"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Hiqni Vijuesin"

, "Compose email"
: "Krijo E-Poste"

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(si pjesëtar i grupit)"

, "External Attendee"
: "Vijues i Jashtem"

, "Originally"
: "Fillimisht"

, "Checking Calendar Data..."
: "Duke kontrolluar të dhënat e kalendarit..."

, "Reply to Recurring Event"
: "Përgjigju Ngjarjes Periodike"

, "You are responding to an recurring event. What would you like to do?"
: "Ju po i përgjigjeni një ngjarje periodike. Çfarë doni të bëni?"

, "Respond to whole series"
: "Përgjigju të gjithë serive"

, "Do not respond"
: "Mos u përgjigj"

, "The event of this message does not exist"
: "Ngjarja e këtij mesazhi nuk ekziston"

, "The sender is not authorised to update the event"
: "Dërguesi nuk është i autorizuar te përditësoje këte ngjarje"

, "This message is already processed"
: "Ky mesazh është tashmë i përpunuar"

, "You are not an attendee of this event"
: "Ju nuk jeni në vijim të kësaj ngjarje"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Mesazh i pa mbështetshëm"

, "This is an event invitation for someone else."
: "Kjo është një ftesë ngjarje për dikë tjetër"

, "You have already replied to this event invitation."
: "Ju i jeni përgjigjur tashmë ftesës së kesaj ngjarjeje"

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Ju ka ardhur një ftesë ngjarjeje. Vendosni përgjigjen tuaj tek:"

, "An invited attendee responded to the invitation."
: "Një vijues i ftuar i është përgjigjur ftesës"

, "Unsupported method"
: "Metodë e pa mbështetshme"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Vendosni përshkrimin..."

, "Grants"
: "Të Drejta"

, "This event is originally stored in a calendar you don't have access to."
: "Kjo ngjarje është vendosur fillimisht në një kalendar ku ju nuk kini të drejta"

, "This event is originally stored in {0}"
: "Kjo ngjarje është vendosur fillimisht në {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Kjo ngjarje është shfaqur gjithashtu tek kalendari juaj personal {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Shiko"

, "Saved in"
: "Ruajtur në"

, "Enter description"
: "Fusni përshkrimin"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Data e mbarimit nuk është e vlefshme"

, "End date must be after start date"
: "Data e mbarimit duhet të jetë mbas datës së fillimit"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Data e fillimit nuk është e vlefshme"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "Përmbledhja nuk mund të jetë më e gjatë se 255 karaktere"

, "The summary must have at least 1 character."
: "Përmbledhja duhet të ketë të paktën 1 karakter"

, "Summary too Long"
: "Përmbledhja shumë e gjatë"

, "Summary too Short"
: "Përmbledhja shumë e shkurtër"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Të gjitha ngjarjet e mia"

, "Position on the left time axis, day and week view should start with"
: "Pozicioni i krahut të majte kohor, pamja e ditës dhe javës duhet të fillojë me  "

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Kalendari i paracaktuar"

, "The default calendar for invitations and new events"
: "Kalendari i paracaktuar për ftesa dhe ngjarje të reja"

, "Default Favorite"
: "Të preferuarat e Paracaktuara"

, "The default favorite which is loaded on calendar startup"
: "E preferuara e paracaktuar që ngarkohet në nisje të kalendarit"

, "Get Notification Emails"
: "Merr E-Postë njoftuese"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Niveli i veprimeve që ju doni të njoftoheni. Ju lutem kini parasysh që organizuesit do të marrin njoftimpër të gjithë përditësimet, përfshirë edhe përgjigjet e vijuesëve, derisa kjo preferncë të jetë vendosur në \"Never\""

, "Send Notifications Emails of own Actions"
: "Dërgo E-Postë njoftuese për Veprimet vetjake"

, "Get notifications emails for actions you did yourself"
: "Dërgo E-Postë njoftuese për veprimet që bëre vetë"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Aktivizo Alarmin Standart"

, "New events get a standard alarm as defined below"
: "Ngjarjet e reja marrin një alarm standart siç përcaktohet më poshtë"

, "Standard Alarm Time"
: "Koha e Alarmit Standart"

, "Minutes before the event starts"
: "Minuta përpara se ngjarja të fillojë"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Kalendarë fiks"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Asnjëherë"

, "On invitation and cancellation only"
: "Vetëm në ftesa dhe anullime"

, "On time changes"
: "Në ndryshime të kohës"

, "On all updates but attendee responses"
: "Në të gjithë përditësimet e përgjigjeve të vijuesve"

, "On attendee responses too"
: "Gjithashtu në përgjigje të vijuesve"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Kalendarët zgjidhen gjithmonë në pamvarësi të parametrave të filtrave. Një përdorim i vlefshëmmund të jetë të shfaqet me forcë një kalendar pushimesh"

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Statusi Vijuesi i disponueshëm"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Pa përgjigje"

, "Accepted"
: "E pranuar"

, "Declined"
: "E pa pranuar"

, "Attendee Roles Available"
: "Role Vijuesi të disponueshëm"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Të kërkuara"

, "Optional"
: "Opsionale"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: "Filtroni intervalet kohore per ngjarjet e CalDAV"

, "For how long in the past (in months) the events should be synchronized."
: "Per sa kohe ne te shkuaren (muaj) duhet te sinkronizohen ngjarjet"

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "Kalendari perosnal i %s"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "i panjohur"

, "This contact has been automatically added by the system as an event attender"
: "Ky kontakt u shtua automatikisht nga sistemi si një Vijues ngjarjesh"

, "The email address has been shortened:"
: ""

, "Every %s day"
: "Çdo ditë %s"

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: "Çdo %1$s muaj në %2$s %3$s"

, "Monthly every %1$s %2$s"
: "Përmuajshëm çdo %1$s %2$s"

, "Every %1$s month on the %2$s"
: "Çdo muaj %1$s në %2$s"

, "Monthly on the %1$s"
: "Përmuajshëm në %1$s"

, "Yearly every %1$s %2$s of %3$s"
: "Pervitshem cdo %1$s %2$s te %3$s"

, "Yearly on the %1$s of %2$s"
: "Përvitshëm në %1$s të %2$s"

, "second to last"
: "sekonda në fund"

, "fifth"
: "pestë"

, "st"
: "rë"

, "nd"
: "të"

, "rd"
: "të"

, "th"
: "ët"

, "Start"
: "Fillo"

, "Priority"
: "Prioriteti"

, "Url"
: "Url"

, "Recurrance rule"
: "Rregull i përsëritjes"

, "Is all day event"
: "Është ngjarje e të gjithë ditës"

, "Organizer timezone"
: "Organizues i brezit kohor"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarm për ngjarjen \"%1$s\" në %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Ftesë për ngjarje  \"%1$s\" në %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "Ngjarja \"%1$s\" në %2$s është anulluar"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Ngjarja \"%1$s\" është riplanifikuar nga %2$s në %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Ngjarja \"%1$s\" në %2$s është përditësuar"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s ngjarje e pranuar \"%2$s\" në %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s ngjarje e refuzuar \"%2$s\" në %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Përgjigje e pa qartë nga %1$s për ngjarjen \"%2$s\" në %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Nuk ka përgjigje nga %1$s për ngjarjen \"%2$s\" në %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Ndryshime në vijim për ngjarjen \"%1$s\" në %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Përditësime"

, "This is an event series exception."
: "Ky është një përjashtim"

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s ndryshuar nga \"%2$s\" në \"%3$s\""

, "%1$s has been invited"
: "%1$s është ftuar"

, "%1$s has been removed"
: "%1$s është hequr"

, "%1$s accepted invitation"
: "%1$s pranoi ftesën"

, "%1$s declined invitation"
: "%1$s Nuk pranoi ftesën"

, "Tentative response from %1$s"
: "Përgjigje jo e qartë nga %1$s"

, "No response from %1$s"
: "Nuk ka përgjigje nga %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" përgjigje nga %1$s"

, "Link"
: ""

, "Event details"
: "Detaje të ngjarjes"

, "All events I attend"
: "Të gjithë ngjarjet që unë pres"

, "Awaiting response"
: "Duke pritur përgjigje"

, "Events I have not yet responded to"
: "Ngjarje që nuk i jam përgjigjur"

, "Declined events"
: "Ngjarje të papranuara"

, "Events I have declined"
: "Ngjarje që nuk i kam pranuar"

, "I'm organizer"
: "Unë jam organizues"

, "Events I'm the organizer of"
: "Ngjarje që unë jam organizuesi"

, "manage shared calendars"
: "menaxho kalendarët e ndarë"

, "Create new shared calendars"
: "Krijo kalendarë të rinj të ndarë"

, "manage shared calendars favorites"
: "menaxho preferencalet e kalendarëve të ndarë"

, "Create or update shared calendars favorites"
: "Krijo ose përditëso preferencialet e kalendarëve të ndarë"

, "manage resources"
: "menaxho burimet"

, "All Rights to administrate resources"
: "Të gjithë të drejtat për administrimin e burimeve"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Kalendar"

, "Do you really want to delete this event?"
: "Doni vërtetë të fshini këtë ngjarje?"

, "Resource Grant"
: ""

, "Event"
: "Ngjarje"

, "Attender"
: "Vijues"

, "Resource"
: "Burim"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
